@@ -37,6 +37,7 @@ def get_static_settings():
     AWS_STATIC_S3_SECURE = get_project_env_variable('AWS_STATIC_S3_SECURE',False)
     
     if AWS_STATIC_S3_BUCKET:
+        STATIC_ROOT = AWS_STATIC_S3_BUCKET
         if AWS_STATIC_S3_SECURE:
             AWS_STATIC_S3_SECURE = literal_eval(AWS_STATIC_S3_SECURE.capitalize())
         STATICFILES_STORAGE = 'django_setup.aws_s3.backends.StaticS3Storage'
@@ -45,8 +46,10 @@ def get_static_settings():
         # URL prefix for static files.
         # For local development, we use the default
         STATIC_URL = '/static/'
+        STATIC_ROOT = 'static/'
         STATICFILES_STORAGE = global_settings.STATICFILES_STORAGE
-    return STATIC_URL, STATICFILES_STORAGE, AWS_PRELOAD_METADATA,\
+    return STATIC_URL, STATIC_ROOT, \
+           STATICFILES_STORAGE, AWS_PRELOAD_METADATA,\
            AWS_STATIC_S3_BUCKET, AWS_STATIC_S3_DOMAIN, \
            AWS_STATIC_S3_SECURE, AWS_STATIC_URL_PROTOCOL
 
@@ -58,11 +61,11 @@ def get_media_settings():
     AWS_MEDIA_URL_PROTOCOL = get_project_env_variable('AWS_MEDIA_URL_PROTOCOL','http')
     
     if AWS_MEDIA_S3_BUCKET:
+        MEDIA_ROOT = AWS_MEDIA_S3_BUCKET
         if AWS_MEDIA_S3_SECURE:
             AWS_MEDIA_S3_SECURE = literal_eval(AWS_MEDIA_S3_SECURE.capitalize())
         DEFAULT_FILE_STORAGE = 'django_setup.aws_s3.backends.MediaS3Storage'
         MEDIA_URL = '%s/' % AWS_MEDIA_S3_DOMAIN
-        MEDIA_ROOT = ''
     else:
         # URL prefix for static files.
         # For local development, we use the default
